@@ -8,6 +8,8 @@ server = None
 cert = None
 keep_passwd = False
 elevate = None
+Client = None
+POLKIT_ACTIONS = '/usr/share/polkit-1/actions/'
 TRAY_ICON = os.path.dirname(inspect.getfile(icon)) + '/lockWithe.png'
 TRAY_ICON_OK = os.path.dirname(inspect.getfile(icon)) + '/lockGreen.png'
 TRAY_ICON_ERROR = os.path.dirname(inspect.getfile(icon)) + '/lockRed.png'
